<?php
/**
 * Quick Reply Full. An extension for the phpBB Forum Software package.
 * @copyright (c) 2022, Steve, https://www.stevenclark.eu/phpBB3/
 */

namespace steve\quickreplyfull\event;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;

class main_listener implements EventSubscriberInterface
{
	public static function getSubscribedEvents()
	{
		return [
			'core.viewtopic_assign_template_vars_before'	=> 'template_vars_before',
		];
	}

	protected $auth;
	protected $config;
	protected $language;
	protected $helper;
    protected $request;//
	protected $template;
	protected $user;
	protected $php_ext;
	protected $root_path;

	public function __construct(
		\phpbb\auth\auth $auth,
		\phpbb\config\config $config,
		\phpbb\language\language $language,
		\phpbb\controller\helper $helper,
        \phpbb\request\request $request,//
		\phpbb\template\template $template,
		\phpbb\user $user,
		$php_ext,
		$root_path)
	{
		$this->auth 		= $auth;
		$this->config 		= $config;
		$this->language 	= $language;
		$this->helper 		= $helper;
        $this->request 		= $request;//
		$this->template 	= $template;
		$this->user 		= $user;
		$this->php_ext 		= $php_ext;
		$this->root_path 	= $root_path;
	}

	public function template_vars_before($event)
	{
		$this->language->add_lang('common', 'steve/quickreplyfull');
		$this->language->add_lang('posting');//up

		$this->forum_id = $event['topic_data']['forum_id'];

		$template_vars = [
			'S_BBCODE_ALLOWED'				=> $this->bbcode_status(),
			'BBCODE_STATUS'					=> $this->bbcode_status() ? $this->language->lang('BBCODE_IS_ON', '<a href="' . $this->helper->route('phpbb_help_bbcode_controller') . '">', '</a>') : $this->language->lang('BBCODE_IS_OFF'),
			'S_BBCODE_FLASH'				=> $this->flash_status(),
			'FLASH_STATUS'					=> $this->flash_status() ? $this->language->lang('FLASH_IS_ON') : $this->language->lang('FLASH_IS_OFF'),
			'S_BBCODE_IMG'					=> $this->img_status(),
			'IMG_STATUS'					=> $this->img_status() ? $this->language->lang('IMAGES_ARE_ON') : $this->language->lang('IMAGES_ARE_OFF'),
			'SMILIES_ALLOWED'				=> $this->smilies_status(),
			'SMILIES_STATUS'				=> $this->smilies_status() ? $this->language->lang('SMILIES_ARE_ON') : $this->language->lang('SMILIES_ARE_OFF'),
			'S_LINKS_ALLOWED'				=> $this->url_status(),
			'U_MORE_SMILIES'    			=> append_sid("{$this->root_path}posting.$this->php_ext", 'mode=smilies'),
			'URL_STATUS'					=> $this->url_status() ? $this->language->lang('URL_IS_ON') : $this->language->lang('URL_IS_OFF'),
			'S_BBCODE_QUOTE'				=> true,//
			//u can use quick reply
			//event $tpl_ary = [ 'S_QUICK_REPLY'			=> true,
			'S_QUICK_REPLY_FULL'			=> true,//can use quick reply full
			'S_QUICK_REPLY_FULL_SUBJECT'	=> true,//enable/disable subject field
			//drop down for smilies enable/disable
		];

		$ignore_flood = $this->auth->acl_get('u_ignoreflood') ? true : $this->auth->acl_get('f_ignoreflood', $this->forum_id);
		if (!$this->ignore_flood())
		{
			//$this->user->data['user_lastpost_time'] && (time() - $this->user->data['user_lastpost_time']) < intval($this->config['flood_interval']))
			$last_posttime = $this->user->data['user_lastpost_time'] + $this->config['flood_interval'];
			$template_vars += [
				'LAST_POST_TIME'	=> $this->user->format_date($last_posttime, 'H:i:s a'),
				'LAST_POST_TIME_JS'	=> $this->user->format_date($last_posttime, 'F j, Y g:i:s a'),
			];
		}

		$this->template->assign_vars($template_vars);

		if ($this->bbcode_status())
		{
			if (!function_exists('display_custom_bbcodes'))
			{
				include_once $this->root_path . 'includes/functions_display.' . $this->php_ext;
			}
			display_custom_bbcodes();

			if ($this->smilies_status())
			{
				if (!function_exists('generate_smilies'))
				{
					include_once $this->root_path . 'includes/functions_posting.' . $this->php_ext;
				}
				generate_smilies('inline', 0);
			}
		}
	}

	public function ignore_flood()
	{
		return (bool) $this->auth->acl_get('u_ignoreflood') ? true : $this->auth->acl_get('f_ignoreflood', $this->forum_id);
	}

	public function bbcode_status()
	{
		return (bool) $this->config['allow_bbcode'] && $this->auth->acl_get('f_bbcode', $this->forum_id) ? true : false;
	}

	public function flash_status()
	{
		return (bool) $this->bbcode_status() && $this->config['allow_post_flash'] && $this->auth->acl_get('f_flash', $this->forum_id) ? true : false;
	}

	public function img_status()
	{
		return (bool) $this->bbcode_status() && $this->auth->acl_get('f_img', $this->forum_id) ? true : false;
	}

	public function smilies_status()
	{
		return (bool) $this->config['allow_smilies'] && $this->auth->acl_get('f_smilies', $this->forum_id) ? true : false;
	}

	public function url_status()
	{
		return (bool) $this->config['allow_post_links'] ? true : false;
	}
}
